import Fragment from './fragment.glsl'
import Vertex from './vertex.glsl'
import * as THREE from 'three';
import SketchBase from '../base';
/**
 * 用 u_time 加上一个 sin 函数，来展示图中红色的动态变化
 * GPU 的硬件加速支持我们使用角度，三角函数和指数函数。这里有一些这些函数的介绍：
 *  sin(),
 * cos(),
 *  tan(),
 * asin(),
 * acos(),
 * atan(),
 *  pow(),
 * exp(),
 * log(), sqrt(), abs(), sign(), floor(),
 * ceil(), fract(), mod(), min(), max() 和 clamp()。
 */


export default class Sketch extends SketchBase {
  constructor(el) {
    super(el);
    this.addBox();
    this.anime();
  }
  addBox() {
    let plane = new THREE.PlaneGeometry(50, 50);
    let material = new THREE.ShaderMaterial({
      side: THREE.DoubleSide,
      uniforms: {
        u_time: {
          value: 0
        },
      },
      vertexShader: Vertex,
      fragmentShader: Fragment,
    });
    this.box = new THREE.Mesh(plane, material);
    this.scene.add(this.box);
  }
  anime() {
    this.index = window.requestAnimationFrame(this.anime.bind(this));
    this.box.material.uniforms.u_time.value += 0.01;
    this.render();
  }
}
