import Fragment from './fragment.glsl'
import Vertex from './vertex.glsl'
import * as THREE from 'three';
import SketchBase from '../base';
/**
 * 我们用 gl_FragCoord.xy 除以 u_resolution，对坐标进行了规范化。
 * 这样做是为了使所有的值落在 0.0 到 1.0 之间，这样就可以轻松把 X 或
 *  Y 的值映射到红色或者绿色通道。
 */


export default class Sketch extends SketchBase {
  constructor(el) {
    super(el);
    this.addBox();
    this.anime();
  }
  addBox() {
    let uniforms = {
      u_time: {
        type: "f",
        value: 1.0
      },
      u_resolution: {
        type: "v2",
        value: new THREE.Vector2()
      }
    };
    let plane = new THREE.PlaneGeometry(50, 50);
    let material = new THREE.ShaderMaterial({
      side: THREE.DoubleSide,
      uniforms,
      vertexShader: Vertex,
      fragmentShader: Fragment,
    });
    uniforms.u_resolution.value.x = this.renderer.domElement.width;
    uniforms.u_resolution.value.y = this.renderer.domElement.height;
    this.box = new THREE.Mesh(plane, material);
    this.scene.add(this.box);
  }
  anime() {
    this.index = window.requestAnimationFrame(this.anime.bind(this));
    this.box.material.uniforms.u_time.value += 0.01;
    this.render();
  }
}
