import * as THREE from 'three';
import {
  OrbitControls
} from 'three/examples/jsm/controls/OrbitControls'

let debug = true;

export default class Sketch {
  constructor(el) {
    this.el = el;
    // 初始化
    this.initParam();
    this.init();
    // 调试
    // this.initAxesHelp();
    // this.initGridHelp();
    // this.initController();
    this.render();
    // 绘制一个圆形
  }
  loop() {
    const Delta = this.clock.getDelta();
    this.index = window.requestAnimationFrame(this.loop.bind(this));
    this.render();
  }

  initParam() {
    let rect = this.el.getClientRects()[0];
    this.width = rect.width;
    this.height = rect.height;
    this.aspect = this.width / this.height;
    this.clock = new THREE.Clock();
  }
  init() {
    // 场景
    this.scene = new THREE.Scene();
    this.scene.background = new THREE.Color('#eeeeee');
    // 摄像机
    this.camera = new THREE.PerspectiveCamera(75, this.aspect, 0.1, 1000);
    this.camera.position.set(0, 1, 3);
    this.camera.lookAt(0, 0, 0);
    // 渲染
    this.renderer = new THREE.WebGLRenderer({
      antialias: true,
      alpha: true,
    });
    this.renderer.setSize(this.width, this.height);
    this.renderer.render(this.scene, this.camera);
    this.renderer.setPixelRatio = window.Pixi
    this.el.appendChild(this.renderer.domElement);
  }
  initAxesHelp() {
    this.axesHelper = new THREE.AxesHelper(100);
    this.scene.add(this.axesHelper);
  }
  initGridHelp() {
    this.gridHelper = new THREE.GridHelper(100, 100);
    this.scene.add(this.gridHelper);
  }
  initController() {
    const that = this;
    this.controller = new OrbitControls(this.camera, this.renderer.domElement);
    this.controller.addEventListener('change', function () {
      that.renderer.render(that.scene, that.camera);
    })
  }
  render() {
    this.renderer.render(this.scene, this.camera);
  }
  destory() {
    if (this.index) {
      window.cancelAnimationFrame(this.index);
    }
  }
}
